@@ -203,6 +203,8 @@ describe Tmuxinator::Config do
       "!@#^%" => 0.0,
       "2.9ä" => 2.9,
       "v3.5" => 3.5,
+      "v3.6" => 3.6,
+      "v3.6a" => 3.6,
       "v3.12.0" => 3.12,
       "v3.12.5" => 3.12
     }.freeze
