@@ -37,6 +37,10 @@ describe Tmuxinator::Project do
     FactoryBot.build(:project_with_alias)
   end
 
+  let(:project_with_append) do
+    FactoryBot.build(:project_with_append)
+  end
+
   it "should include Hooks" do
     expect(project).to be_kind_of(Tmuxinator::Hooks::Project)
   end
@@ -46,6 +50,21 @@ describe Tmuxinator::Project do
       it "creates an instance" do
         expect(project).to be_a(Tmuxinator::Project)
       end
+
+      it "validates append outside a current session" do
+        Tmuxinator::Project.any_instance.stub(tmux_has_session?: false)
+        expect { project_with_append }.to(
+          raise_error(
+            RuntimeError,
+            "Cannot append to a session that does not exist"
+          )
+        )
+      end
+
+      it "validates append within a current session" do
+        Tmuxinator::Project.any_instance.stub(tmux_has_session?: true)
+        expect { project_with_append }.to_not raise_error
+      end
     end
   end
 
@@ -262,6 +281,16 @@ describe Tmuxinator::Project do
         end
       end
     end
+
+    context "no_pre_window option is true" do
+      before do
+        allow(project).to receive_messages(no_pre_window: true)
+      end
+
+      it "returns nil" do
+        expect(pre_window).to be_nil
+      end
+    end
   end
 
   describe "#socket" do
@@ -368,6 +397,17 @@ describe Tmuxinator::Project do
         expect(project.base_index).to eq 0
       end
     end
+
+    context "with append set" do
+      before do
+        Tmuxinator::Project.any_instance.stub(tmux_has_session?: true)
+        project_with_append.stub(last_window_index: 3)
+      end
+
+      it "defaults to the next window index" do
+        expect(project_with_append.base_index).to eq 4
+      end
+    end
   end
 
   describe "#startup_window" do
@@ -410,6 +450,13 @@ describe Tmuxinator::Project do
     it "gets the window and index for tmux" do
       expect(project.window(1)).to eq "sample:1"
     end
+
+    context "with append set" do
+      it "excludes the session name" do
+        Tmuxinator::Project.any_instance.stub(tmux_has_session?: true)
+        expect(project_with_append.window(1)).to eq ":1"
+      end
+    end
   end
 
   describe "#name?" do
@@ -576,6 +623,13 @@ describe Tmuxinator::Project do
         expect(project.tmux_new_session_command).to eq command
       end
     end
+
+    context "with append set" do
+      it "returns nothing" do
+        Tmuxinator::Project.any_instance.stub(tmux_has_session?: true)
+        expect(project_with_append.tmux_new_session_command).to be_nil
+      end
+    end
   end
 
   describe "tmux_kill_session_command" do
@@ -611,7 +665,7 @@ describe Tmuxinator::Project do
   end
 
   describe "::parse_settings" do
-    let(:args) { ["one", "two=three"] }
+    let(:args) { ["one", "two=three", "four=five=six"] }
 
     it "returns settings in a hash" do
       expect(described_class.parse_settings(args)["two"]).to eq("three")
@@ -621,6 +675,10 @@ describe Tmuxinator::Project do
       described_class.parse_settings(args)
       expect(args).to eq(["one"])
     end
+
+    it "handles equals signs in values" do
+      expect(described_class.parse_settings(args)["four"]).to eq("five=six")
+    end
   end
 
   describe "#validate!" do
